roc.dingo.models
================

This directory contains the migrations auto generated by Alembic:

- check the generated code
- adjust the code if needed

Note:

- You can change the name of migrations for something more friendly
- Generation of the initial revision can be done with the following command: `pop db makemigrations roc.dingo --rev-id='roc_dingo_0001_initial' --head="poppy_pop_0002_version_num"`
- Make sure to create the 'pipeline' schema in the initial revision and to get the expected user permissions
- Make sure to have a up-to-date database before creating a new migration. Run the command `pop -ll INFO db upgrade heads` to have the last database version.
- The 'pipeline' schema is deleted by initial downgrade migration
